# -*- coding: utf-8 -*-
from __future__ import unicode_literals, absolute_import, division
from ._version import __version__, __version_info__  # noqa
from .app import configure


__all__ = [
    'configure',
]
